==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/value/ignored_value_definition.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'ignored_value_definition'} = {
  'contents' => [
    {
      'contents' => [
        {
          'args' => [
            {
              'parent' => {},
              'text' => 'aa',
              'type' => 'misc_arg'
            },
            {
              'parent' => {},
              'text' => 'outside',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'set',
          'extra' => {
            'arg_line' => ' aa outside
',
            'misc_args' => [
              'aa',
              'outside'
            ]
          },
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'tex'
                    }
                  ],
                  'parent' => {},
                  'type' => 'brace_command_arg'
                },
                {
                  'parent' => {},
                  'type' => 'elided'
                }
              ],
              'cmdname' => 'inlinefmt',
              'extra' => {
                'format' => 'tex'
              },
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'outside.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'args'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[4];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'ignored_value_definition'}{'contents'}[0];
$result_trees{'ignored_value_definition'}{'contents'}[0]{'parent'} = $result_trees{'ignored_value_definition'};

$result_texis{'ignored_value_definition'} = '@set aa outside

@inlinefmt{tex,}

outside.
';


$result_texts{'ignored_value_definition'} = '


outside.
';

$result_errors{'ignored_value_definition'} = [];


$result_floats{'ignored_value_definition'} = {};


1;

==> texinfo_7.1.orig.tar.xz: texinfo-7.1/tp/t/results/value/ignored_value_definition.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'ignored_value_definition'} = {
  'contents' => [
    {
      'contents' => [
        {
          'args' => [
            {
              'text' => 'aa',
              'type' => 'rawline_arg'
            },
            {
              'text' => 'outside',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'set',
          'info' => {
            'arg_line' => ' aa outside
'
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => 'tex'
                    }
                  ],
                  'type' => 'brace_command_arg'
                },
                {
                  'contents' => [
                    {
                      'text' => '
@set aa in inlinefmt tex
',
                      'type' => 'raw'
                    }
                  ],
                  'type' => 'elided_brace_command_arg'
                }
              ],
              'cmdname' => 'inlinefmt',
              'extra' => {
                'format' => 'tex'
              },
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'text' => '
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'source_marks' => [
            {
              'counter' => 1,
              'element' => {
                'args' => [
                  {
                    'text' => 'aa'
                  }
                ],
                'cmdname' => 'value'
              },
              'line' => 'outside',
              'position' => 1,
              'sourcemark_type' => 'value_expansion',
              'status' => 'start'
            }
          ],
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'source_marks' => [
                {
                  'counter' => 1,
                  'position' => 7,
                  'sourcemark_type' => 'value_expansion',
                  'status' => 'end'
                }
              ],
              'text' => 'outside.
'
            }
          ],
          'type' => 'paragraph'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'ignored_value_definition'} = '@set aa outside

@inlinefmt{tex,
@set aa in inlinefmt tex
}

outside.
';


$result_texts{'ignored_value_definition'} = '


outside.
';

$result_errors{'ignored_value_definition'} = [];


$result_floats{'ignored_value_definition'} = {};


1;
